        function getT(rr,cc){
       if(rr==3 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260426 a 12</strong> UTC HH+120 (rango:108-132)<br><strong>control +<br>EPS</strong>';}
       if(rr==3 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260426 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>1</strong> representante: <strong>0</strong> miembros: 27 <strong>control</strong><br>0,1,2,3,5,8,14,15,16,19,20,22,24,25,28,29,30,32,34,37,39,40,42,44,45,48,50';}
       if(rr==3 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260426 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>2</strong> representante: <strong>21</strong> miembros: 17 <br>4,7,9,12,13,17,18,21,26,27,31,33,35,36,38,43,46';}
       if(rr==3 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260426 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>3</strong> representante: <strong>47</strong> miembros: 7 <br>6,10,11,23,41,47,49';}
       if(rr==17 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260426 a 12</strong> UTC HH+120 (rango:108-132)<br><strong>control +<br>EPS</strong>';}
       if(rr==17 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260426 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>1</strong> representante: <strong>0</strong> miembros: 27 <strong>control</strong><br>0,1,2,3,5,8,14,15,16,19,20,22,24,25,28,29,30,32,34,37,39,40,42,44,45,48,50';}
       if(rr==17 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260426 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>2</strong> representante: <strong>21</strong> miembros: 17 <br>4,7,9,12,13,17,18,21,26,27,31,33,35,36,38,43,46';}
       if(rr==17 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260426 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>3</strong> representante: <strong>47</strong> miembros: 7 <br>6,10,11,23,41,47,49';}
       if(rr==19 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260426 a 12</strong> UTC HH+120 (rango:108-132)<br><strong>control +<br>EPS</strong>';}
       if(rr==19 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260426 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>1</strong> representante: <strong>0</strong> miembros: 27 <strong>control</strong><br>0,1,2,3,5,8,14,15,16,19,20,22,24,25,28,29,30,32,34,37,39,40,42,44,45,48,50';}
       if(rr==19 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260426 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>2</strong> representante: <strong>21</strong> miembros: 17 <br>4,7,9,12,13,17,18,21,26,27,31,33,35,36,38,43,46';}
       if(rr==19 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260426 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>3</strong> representante: <strong>47</strong> miembros: 7 <br>6,10,11,23,41,47,49';}
       if(rr==20 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260426 a 12</strong> UTC HH+120 (rango:108-132)<br><strong>control +<br>EPS</strong>';}
       if(rr==20 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260426 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>1</strong> representante: <strong>0</strong> miembros: 27 <strong>control</strong><br>0,1,2,3,5,8,14,15,16,19,20,22,24,25,28,29,30,32,34,37,39,40,42,44,45,48,50';}
       if(rr==20 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260426 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>2</strong> representante: <strong>21</strong> miembros: 17 <br>4,7,9,12,13,17,18,21,26,27,31,33,35,36,38,43,46';}
       if(rr==20 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260426 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>3</strong> representante: <strong>47</strong> miembros: 7 <br>6,10,11,23,41,47,49';}
       if(rr==21 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260426 a 12</strong> UTC HH+120 (rango:108-132)<br><strong>control +<br>EPS</strong>';}
       if(rr==21 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260426 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>1</strong> representante: <strong>0</strong> miembros: 27 <strong>control</strong><br>0,1,2,3,5,8,14,15,16,19,20,22,24,25,28,29,30,32,34,37,39,40,42,44,45,48,50';}
       if(rr==21 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260426 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>2</strong> representante: <strong>21</strong> miembros: 17 <br>4,7,9,12,13,17,18,21,26,27,31,33,35,36,38,43,46';}
       if(rr==21 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260426 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>3</strong> representante: <strong>47</strong> miembros: 7 <br>6,10,11,23,41,47,49';}
       if(rr==22 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260426 a 12</strong> UTC HH+120 (rango:108-132)<br><strong>control +<br>EPS</strong>';}
       if(rr==22 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260426 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>1</strong> representante: <strong>0</strong> miembros: 27 <strong>control</strong><br>0,1,2,3,5,8,14,15,16,19,20,22,24,25,28,29,30,32,34,37,39,40,42,44,45,48,50';}
       if(rr==22 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260426 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>2</strong> representante: <strong>21</strong> miembros: 17 <br>4,7,9,12,13,17,18,21,26,27,31,33,35,36,38,43,46';}
       if(rr==22 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260426 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>3</strong> representante: <strong>47</strong> miembros: 7 <br>6,10,11,23,41,47,49';}
}
